@@ -25,13 +25,14 @@
 #' @param datapath destination directory where to download store the file
 #' @param progress print progress while downloading
 #' @references [tesseract wiki: training data](https://github.com/tesseract-ocr/tesseract/wiki/Data-Files)
-#' @examples \dontrun{
-#' tesseract_download("fra")
+#' @examples \donttest{
+#' if(is.na(match("fra", tesseract_info()$available)))
+#'   tesseract_download("fra")
 #' french <- tesseract("fra")
 #' text <- ocr("https://jeroen.github.io/images/french_text.png", engine = french)
 #' cat(text)
 #' }
-tesseract_download <- function(lang, datapath = NULL, progress = TRUE){
+tesseract_download <- function(lang, datapath = NULL, progress = interactive()){
   if(!length(datapath)){
     warn_on_linux()
     datapath <- tesseract_info()$datapath
